-- 	File: lane_output_checker.vhd
--
--	© COPYRIGHT 2014 TOPIC EMBEDDED PRODUCTS B.V. ALL RIGHTS RESERVED.
--
--	This file contains confidential and proprietary information of
--	Topic Embedded Products B.V. and is protected under Dutch and
--	International copyright and other international intellectual property laws.
--
--	Disclaimer
--
--	This disclaimer is not a license and does not grant any rights to the
--	materials distributed herewith. Except as otherwise provided in a valid
--	license issued to you by Topic Embedded Products B.V., and to the maximum
--	extend permitted by applicable law:
--
--	1.	Dyplo is furnished on an "as is", as available basis. Topic makes no
--	warranty, express or implied, with respect to the capability of Dyplo. All
--	warranties of any type, express or implied, including the warranties of
--	merchantability, fitness for a particular purpose and non-infringement of
--	third party rights are expressly disclaimed.
--
--	2.	Topic's maximum total liability shall be limited to general money
--	damages in an amount not to exceed the total amount paid for in the year
--	in which the damages have occurred.  Under no circumstances including
--	negligence shall Topic be liable for direct, indirect, incidental, special,
--	consequential or punitive damages, or for loss of profits, revenue, or data,
--	that are directly or indirectly related to the use of, or the inability to
--	access and use Dyplo and related services, whether in an action in contract,
--	tort, product liability, strict liability, statute or otherwise even if
--	Topic has been advised of the possibility of those damages.
--
--	This copyright notice and disclaimer must be retained as part of this file at all times.


library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

library dyplo;
use dyplo.dyplo_types.all;
use dyplo.dyplo_config.all;

library dyplo_test;
use dyplo_test.test_types.all;

entity lane_output_checker is
	generic(
		CONNECT_LANES : natural range 1 to 4  := 2;
		CONNECT_ID    : natural range 0 to 31 := 1
	);
	port(
		clk               : in  std_logic;
		rst               : in  std_logic;
		lane_destinations : in  lane_destinations_type;
		lanes             : in  data_lanes_type;
		captured_on_lanes : out unsigned_matrix_8_4_64
	);
end lane_output_checker;

architecture Behavioral of lane_output_checker is
	signal input_cnt : unsigned_matrix_8_4_64 := (others => (others => (others => '0')));
begin
	
	captured_on_lanes <= input_cnt;
	
	lanes_gen : for i in 0 to CONNECT_LANES - 1 generate
	begin
		process(clk)
		begin
			if (rising_edge(clk)) then
				if (rst = '1') then
				else
					if (lanes(i).tvalid = '1') then
						-- check if data matches expected data (sequence)
						if (std_logic_vector(input_cnt(to_integer(unsigned(lanes(i).tnode_id)))(to_integer(unsigned(lanes(i).tstream_id)))) /= lanes(i).tdata) then
							report "Data on lane does not match the expected data" severity failure;
						end if;
					end if;

				end if;
			end if;
		end process;
	end generate;
	
	-- Keep track of counters per node_id,stream_id (NOT per lane,node_id,stream_id)
	process(clk)
	begin
		if (rising_edge(clk)) then
			if (rst = '1') then	
				input_cnt <= (others => (others => (others => '0')));
			else
				for i in 0 to CONNECT_LANES - 1 loop
					if(lanes(i).tvalid = '1') then
						input_cnt(to_integer(unsigned(lanes(i).tnode_id)))(to_integer(unsigned(lanes(i).tstream_id))) <= input_cnt(to_integer(unsigned(lanes(i).tnode_id)))(to_integer(unsigned(lanes(i).tstream_id))) + 1;
					end if;
				end loop;
			end if;
		end if;
	end process;
	

	-- check if there are multiple data words on the lanes with the same destination node
	process(clk)
	begin
		if (rising_edge(clk)) then
			if (rst = '1') then
			else
				for i in 0 to CONNECT_LANES - 1 loop
					if (lanes(i).tvalid = '1') then
						for j in 0 to CONNECT_LANES - 1 loop
							if (j /= i) then
								if (lanes(j).tvalid = '1' and (lanes(j).tnode_id = lanes(i).tnode_id)) then
									report "There are multiple data words on the backplane lanes (output) (next to each other) with the same destination" severity failure;
								end if;
							end if;
						end loop;
					end if;
				end loop;
			end if;
		end if;
	end process;

end Behavioral;







