-- 	File: axi_lvds_e.vhd
--	
--	� COPYRIGHT 2014 TOPIC EMBEDDED PRODUCTS B.V. ALL RIGHTS RESERVED.
--	
--	This file contains confidential and proprietary information of 
--	Topic Embedded Products B.V. and is protected under Dutch and 
--	International copyright and other international intellectual property laws.
--	
--	Disclaimer
--	
--	This disclaimer is not a license and does not grant any rights to the 
--	materials distributed herewith. Except as otherwise provided in a valid 
--	license issued to you by Topic Embedded Products B.V., and to the maximum 
--	extend permitted by applicable law:
--
--	1.	Dyplo is furnished on an "as is", as available basis. Topic makes no 
--	warranty, express or implied, with respect to the capability of Dyplo. All 
--	warranties of any type, express or implied, including the warranties of 
--	merchantability, fitness for a particular purpose and non-infringement of 
--	third party rights are expressly disclaimed.
--	
--	2.	Topic's maximum total liability shall be limited to general money 
--	damages in an amount not to exceed the total amount paid for in the year 
--	in which the damages have occurred.  Under no circumstances including 
--	negligence shall Topic be liable for direct, indirect, incidental, special, 
--	consequential or punitive damages, or for loss of profits, revenue, or data, 
--	that are directly or indirectly related to the use of, or the inability to 
--	access and use Dyplo and related services, whether in an action in contract, 
--	tort, product liability, strict liability, statute or otherwise even if 
--	Topic has been advised of the possibility of those damages. 
--	
--	This copyright notice and disclaimer must be retained as part of this file at all times.

library IEEE;
use ieee.std_logic_1164.ALL;
use ieee.numeric_std.all;

-- Uncomment the following library declaration if using
-- arithmetic functions with Signed or Unsigned values
--use IEEE.NUMERIC_STD.ALL;

-- Uncomment the following library declaration if instantiating
-- any Xilinx leaf cells in this code.
library UNISIM;
use UNISIM.VComponents.all;

entity axi_lvds is
  generic (
    -- AXI4-Lite bus related configuration parameters
    C_S_AXI_DATA_WIDTH          : integer     := 32;
    C_S_AXI_ADDR_WIDTH          : integer     := 32;
    -- AXI4-Stream bus related configuration parameters
    C_S_AXIS_TDATA_WIDTH        : integer     := 64;
    C_S_AXIS_TUSER_WIDTH        : integer     := 1;
    S_S_AXIS_TKEEP_WIDTH        : integer     := 8  
  );
  port ( 
    ------------ AXI-4 Lite Interface -------
    S_AXI_ACLK                  : in  std_logic;
    S_AXI_ARESETN               : in  std_logic;
    S_AXI_AWADDR                : in  std_logic_vector(C_S_AXI_ADDR_WIDTH - 1 downto 0);
    S_AXI_AWVALID               : in  std_logic;
    S_AXI_AWREADY               : out std_logic;
    S_AXI_WDATA                 : in  std_logic_vector(C_S_AXI_DATA_WIDTH - 1 downto 0);
    S_AXI_WSTRB                 : in  std_logic_vector(3 downto 0);
    S_AXI_WVALID                : in  std_logic;
    S_AXI_WREADY                : out std_logic;
    S_AXI_BRESP                 : out std_logic_vector(1 downto 0);
    S_AXI_BVALID                : out std_logic;
    S_AXI_BREADY                : in  std_logic;
    S_AXI_ARADDR                : in  std_logic_vector(C_S_AXI_ADDR_WIDTH - 1 downto 0);
    S_AXI_ARVALID               : in  std_logic;
    S_AXI_ARREADY               : out std_logic;
    S_AXI_RDATA                 : out std_logic_vector(C_S_AXI_DATA_WIDTH - 1 downto 0);
    S_AXI_RRESP                 : out std_logic_vector(1 downto 0);
    S_AXI_RVALID                : out std_logic;
    S_AXI_RREADY                : in  std_logic;
    ------------ AXI-4 Streaming Interface -------
    S_AXIS_ACLK                 : in  std_logic;
    S_AXIS_ARESETN              : in  std_logic;
    S_AXIS_TVALID               : in  std_logic; 
    S_AXIS_TREADY               : out std_logic; 
    S_AXIS_TDATA                : in  std_logic_vector(C_S_AXIS_TDATA_WIDTH - 1 downto 0);
    S_AXIS_TKEEP                : in  std_logic_vector(S_S_AXIS_TKEEP_WIDTH - 1 downto 0); 
    S_AXIS_TLAST                : in  std_logic; 
    S_AXIS_TUSER                : in  std_logic_vector(C_S_AXIS_TUSER_WIDTH - 1 downto 0);
    ------------ TFT LVDS video -----------------
    lvds_channel_0_p            : out std_logic;
    lvds_channel_0_n            : out std_logic;
    lvds_channel_1_p            : out std_logic;
    lvds_channel_1_n            : out std_logic;
    lvds_channel_2_p            : out std_logic;
    lvds_channel_2_n            : out std_logic;
    lvds_clk_p                  : out std_logic;
    lvds_clk_n                  : out std_logic;
    ------------ TFT backlight -----------------
    backlight_en                : out std_logic;
    backlight_pwm               : out std_logic;  
    pwm_clock                   : in std_logic; -- must be between 100 MHz and 1 GHz  
    ------------ pixel clock -----------------
    pixel_clk                   : in std_logic;
    pixel_clk_locked            : in std_logic;
    ------------ frame sync ------------------
    mm2s_fsync                  : out std_logic;
    ------------ video out, for debugging -------
    R                           : out std_logic_vector(3 downto 0);
    G                           : out std_logic_vector(3 downto 0);
    B                           : out std_logic_vector(3 downto 0);
    HS                          : out std_logic;
    VS                          : out std_logic;
    --------------- debug signals ---------------
    lvds_clk_out                : out std_logic   
  );
end axi_lvds;
