#!/bin/sh -e

# Check if in right directory and/or build is run
if [ ! -e fpga.bit ]
then
	echo "File 'fpga.bit' not found."
	exit 1
fi

# For future expansion
case "$FPGA_FAMILY" in
	xczu6eg)
		MACHINE=tdkzu6
		;;
	xczu9eg)
		MACHINE=tdkzu9
		;;
	xczu15eg)
		MACHINE=tdkzu15
		;;
	*)
		echo "Environment variable FPGA_FAMILY=$FPGA_FAMILY is not valid"
		echo "Valid are: xczu6eg xczu9eg xczu15eg"
		exit 1
		;;
esac

PART=${FPGA_FAMILY}-ffvb1156-1-i

if [ ! -e "${PART}.xsa" ]
then
	echo "File '${PART}.xsa' not found."
	exit 1
fi

PACKAGE_NAME="fpga-image-${MACHINE}-reference"
PACKAGE2_NAME="fpga-hardware-${MACHINE}-reference"

VERSION=`git rev-list HEAD | wc -l`+`git rev-parse --short HEAD`

xz -9 < fpga.bit > ${PACKAGE_NAME}-${VERSION}.bit.xz
xz -9 < "${PART}.xsa" > ${PACKAGE2_NAME}-${VERSION}.xsa.xz
