######## Miami Clock sources ############
# Si514 chip (programmable clock) running at 150 MHz
create_clock -period 6.666 -name clk_fpga [get_ports {clk_fpga_clk_p[0]}]
set_property PACKAGE_PIN AK8 [get_ports {clk_fpga_clk_p[0]}]
set_property IOSTANDARD LVDS [get_ports {clk_fpga_clk_p[0]}]
# Si511 chip frequency: 200 Mhz
create_clock -period 5.0 -name clk_200Mhz [get_ports {clk_200Mhz_clk_p[0]}]
set_property PACKAGE_PIN AL8 [get_ports {clk_200Mhz_clk_p[0]}]
set_property IOSTANDARD LVDS [get_ports {clk_200Mhz_clk_p[0]}]
set_property PACKAGE_PIN AK9 [get_ports {clk_200MHz_en[0]}]
set_property IOSTANDARD LVCMOS18 [get_ports {clk_200MHz_en[0]}]

# Output 150MHz SATA ref clock through loopback on Florida to GTX clock
set_property PACKAGE_PIN AH12 [get_ports {clk_sata_out_p}] 
set_property PACKAGE_PIN AH11 [get_ports {clk_sata_out_n}] 
set_property IOSTANDARD LVDS [get_ports {clk_sata_out_p}]

################ LEDs ###############
# Miami User LED
set_property IOSTANDARD LVCMOS18 [get_ports {userLED[0]}]
set_property PACKAGE_PIN AM9 [get_ports {userLED[0]}]

# Florida LEDs in order: D4(RED), D3(YELLOW), D2(GREEN), D5(GREEN), D6(GREEN)
set_property PACKAGE_PIN N11 [get_ports {LEDS[4]}]
set_property PACKAGE_PIN C16 [get_ports {LEDS[3]}]
set_property PACKAGE_PIN D16 [get_ports {LEDS[2]}]
set_property PACKAGE_PIN AH3 [get_ports {LEDS[1]}]
set_property PACKAGE_PIN AD1 [get_ports {LEDS[0]}]
set_property IOSTANDARD LVCMOS18 [get_ports {LEDS[4]}]
set_property IOSTANDARD LVCMOS33 [get_ports {LEDS[3]}]
set_property IOSTANDARD LVCMOS33 [get_ports {LEDS[2]}]
set_property IOSTANDARD LVCMOS18 [get_ports {LEDS[1]}]
set_property IOSTANDARD LVCMOS18 [get_ports {LEDS[0]}]

########## PMOD#0 on Florida ########
# in [0]..[3] map to pin number 1..4
set_property PACKAGE_PIN J12 [get_ports {pmod_0_tri_io[0]}]
set_property PACKAGE_PIN H12 [get_ports {pmod_0_tri_io[1]}]
set_property PACKAGE_PIN F17 [get_ports {pmod_0_tri_io[2]}]
set_property PACKAGE_PIN F18 [get_ports {pmod_0_tri_io[3]}]
# in [4]..[7] map to pin number 7..10
set_property PACKAGE_PIN L17 [get_ports {pmod_0_tri_io[4]}]
set_property PACKAGE_PIN K17 [get_ports {pmod_0_tri_io[5]}]
set_property PACKAGE_PIN G15 [get_ports {pmod_0_tri_io[6]}]
set_property PACKAGE_PIN G14 [get_ports {pmod_0_tri_io[7]}]
set_property IOSTANDARD LVCMOS33 [get_ports pmod_0*]

########## PMOD#1 on Florida ########
# in [0]..[3] map to pin number 1..4
set_property PACKAGE_PIN C12 [get_ports {pmod_1_tri_io[0]}]
set_property PACKAGE_PIN B12 [get_ports {pmod_1_tri_io[1]}]
set_property PACKAGE_PIN A13 [get_ports {pmod_1_tri_io[2]}]
set_property PACKAGE_PIN A12 [get_ports {pmod_1_tri_io[3]}]
# in [4]..[7] map to pin number 7..10
set_property PACKAGE_PIN B16 [get_ports {pmod_1_tri_io[4]}]
set_property PACKAGE_PIN A16 [get_ports {pmod_1_tri_io[5]}]
set_property PACKAGE_PIN C13 [get_ports {pmod_1_tri_io[6]}]
set_property PACKAGE_PIN B13 [get_ports {pmod_1_tri_io[7]}]
set_property IOSTANDARD LVCMOS33 [get_ports pmod_1_*]

########## PMOD#2 on Florida (SPI interface) ########
set_property PACKAGE_PIN J14 [get_ports {pmod2_spi_ss}]
set_property PACKAGE_PIN H14 [get_ports {pmod2_spi_mosi}]
set_property PACKAGE_PIN E14 [get_ports {pmod2_spi_miso}]
set_property PACKAGE_PIN D14 [get_ports {pmod2_spi_sck}]
set_property PACKAGE_PIN F13 [get_ports {pmod2_int}]
set_property PACKAGE_PIN E13 [get_ports {pmod2_rst}]
set_property PACKAGE_PIN E12 [get_ports {pmod2_ns9}]
set_property PACKAGE_PIN D12 [get_ports {pmod2_ns10}]
set_property IOSTANDARD LVCMOS33 [get_ports pmod2_*]

# Ethernet RGMII on Florida
create_clock -period 8.000 -name rgmii_rxc [get_ports RGMII_rxc]
set_property PACKAGE_PIN AE5 [get_ports RGMII_rxc]
set_property PACKAGE_PIN AH6 [get_ports RGMII_rx_ctl]
set_property PACKAGE_PIN AD7 [get_ports {RGMII_rd[0]}]
set_property PACKAGE_PIN AD6 [get_ports {RGMII_rd[1]}]
set_property PACKAGE_PIN AH4 [get_ports {RGMII_rd[2]}]
set_property PACKAGE_PIN AJ4 [get_ports {RGMII_rd[3]}]
set_property PACKAGE_PIN AF7 [get_ports RGMII_txc]
set_property PACKAGE_PIN AG6 [get_ports RGMII_tx_ctl]
set_property PACKAGE_PIN AF5 [get_ports {RGMII_td[0]}]
set_property PACKAGE_PIN AF1 [get_ports {RGMII_td[1]}]
set_property PACKAGE_PIN AE4 [get_ports {RGMII_td[2]}]
set_property PACKAGE_PIN AD4 [get_ports {RGMII_td[3]}]

#create_clock -period 8.000 -name rgmii_clk_125 [get_ports RGMII_clk_125]
#set_property PACKAGE_PIN AE7 [get_ports {RGMII_clk_125}]

set_property PACKAGE_PIN AG9 [get_ports -regexp -nocase mdio_phy_mdc]
set_property PACKAGE_PIN AG10 [get_ports -regexp -nocase mdio_phy_mdio_io]
set_property PACKAGE_PIN AF11 [get_ports eth_reset_n]
set_property PACKAGE_PIN AG11 [get_ports eth_int_n]

set_property IOSTANDARD LVCMOS18 [get_ports -regexp -nocase .*RGMII_.*]
set_property IOSTANDARD LVCMOS18 [get_ports -regexp -nocase mdio_phy_mdc]
set_property IOSTANDARD LVCMOS18 [get_ports -regexp -nocase mdio_phy_mdio_io]
set_property IOSTANDARD LVCMOS18 [get_ports eth_*]

# This parameter is needed to pass bitstream generation (calibration only needed for memory interfaces)
set_property UNAVAILABLE_DURING_CALIBRATION TRUE [get_ports -regexp -nocase .*RGMII_.*]

######## Buttons #########
set_property PACKAGE_PIN G19 [get_ports button_s2]
set_property IOSTANDARD LVCMOS33 [get_ports button_s2]
set_property PULLUP true [get_ports button_s2]
set_property PACKAGE_PIN AH7 [get_ports button_s3]
set_property IOSTANDARD LVCMOS18 [get_ports button_s3]
set_property PULLUP true [get_ports button_s3]

# This parameter is needed to pass bitstream generation (calibration only needed for memory interfaces)
set_property UNAVAILABLE_DURING_CALIBRATION TRUE [get_ports button_s3]

# UART1 on Florida
set_property PACKAGE_PIN C14 [get_ports UART_1_ctsn]
set_property PACKAGE_PIN B14 [get_ports UART_1_rxd]
set_property PULLUP true [get_ports UART_1_rxd]
set_property PACKAGE_PIN A15 [get_ports UART_1_rtsn]
set_property PACKAGE_PIN D17 [get_ports UART_1_txd]
set_property IOSTANDARD LVCMOS33 [get_ports -regexp -nocase UART_1_.*]

# HDMI out
#set_property PACKAGE_PIN AA11 [get_ports {hdmi_out_spdif}]
set_property PACKAGE_PIN AA10 [get_ports {hdmi_out_vs}] 
set_property PACKAGE_PIN V8   [get_ports {hdmi_out_hs}] 
set_property PACKAGE_PIN V7   [get_ports {hdmi_out_de}]
set_property PACKAGE_PIN AA7  [get_ports {hdmi_out_clk}]
# HDMI out bits 0..7 map to D4..D11
set_property PACKAGE_PIN N9   [get_ports {hdmi_out_data[0]}]
set_property PACKAGE_PIN N8   [get_ports {hdmi_out_data[1]}]
set_property PACKAGE_PIN AC1  [get_ports {hdmi_out_data[2]}]
set_property PACKAGE_PIN AC2  [get_ports {hdmi_out_data[3]}]
set_property PACKAGE_PIN U5   [get_ports {hdmi_out_data[4]}]
set_property PACKAGE_PIN U4   [get_ports {hdmi_out_data[5]}]
set_property PACKAGE_PIN AC4  [get_ports {hdmi_out_data[6]}]
set_property PACKAGE_PIN AB4  [get_ports {hdmi_out_data[7]}]
# HDMI out bits 8..15 map to D16..D23
set_property PACKAGE_PIN AA2  [get_ports {hdmi_out_data[8]}]
set_property PACKAGE_PIN AC3  [get_ports {hdmi_out_data[9]}]
set_property PACKAGE_PIN V3   [get_ports {hdmi_out_data[10]}]
set_property PACKAGE_PIN AB3  [get_ports {hdmi_out_data[11]}]
set_property PACKAGE_PIN L10  [get_ports {hdmi_out_data[12]}]
set_property PACKAGE_PIN V4   [get_ports {hdmi_out_data[13]}]
set_property PACKAGE_PIN AA1  [get_ports {hdmi_out_data[14]}]
set_property PACKAGE_PIN M10  [get_ports {hdmi_out_data[15]}]
# HDMI out bits 16..23 map to D28..D35
set_property PACKAGE_PIN U11  [get_ports {hdmi_out_data[16]}]
set_property PACKAGE_PIN T11  [get_ports {hdmi_out_data[17]}]
set_property PACKAGE_PIN R10  [get_ports {hdmi_out_data[18]}]
set_property PACKAGE_PIN R9   [get_ports {hdmi_out_data[19]}]
set_property PACKAGE_PIN T8   [get_ports {hdmi_out_data[20]}]
set_property PACKAGE_PIN R8   [get_ports {hdmi_out_data[21]}]
set_property PACKAGE_PIN T12  [get_ports {hdmi_out_data[22]}]
set_property PACKAGE_PIN R12  [get_ports {hdmi_out_data[23]}]
# HDMI-out IO voltage
set_property IOSTANDARD LVCMOS18 [get_ports -regexp -nocase hdmi_out_.*]

# HDMI in
create_clock -period 6.061 -name hdmi_in_clk [get_ports hdmi_in_llc]
set_property PACKAGE_PIN AH1 [get_ports {hdmi_in_hs}]
set_property PACKAGE_PIN AD2 [get_ports {hdmi_in_vs}]
set_property PACKAGE_PIN AE1 [get_ports {hdmi_in_de}]
set_property PACKAGE_PIN AG5 [get_ports {hdmi_in_int_n}]
set_property PACKAGE_PIN AJ1 [get_ports {hdmi_in_rst_n}]
set_property PACKAGE_PIN K12 [get_ports {hdmi_in_data[23]}]
set_property PACKAGE_PIN L12 [get_ports {hdmi_in_data[22]}]
set_property PACKAGE_PIN AA12 [get_ports {hdmi_in_data[21]}]
set_property PACKAGE_PIN Y12 [get_ports {hdmi_in_data[20]}]
set_property PACKAGE_PIN V11 [get_ports {hdmi_in_data[19]}]
set_property PACKAGE_PIN V12 [get_ports {hdmi_in_data[18]}]
set_property PACKAGE_PIN AC9 [get_ports {hdmi_in_data[17]}]
set_property PACKAGE_PIN AB9 [get_ports {hdmi_in_data[16]}]
set_property PACKAGE_PIN AE10 [get_ports {hdmi_in_data[15]}]
set_property PACKAGE_PIN AF10 [get_ports {hdmi_in_data[14]}]
set_property PACKAGE_PIN AE12 [get_ports {hdmi_in_data[13]}]
set_property PACKAGE_PIN AF12 [get_ports {hdmi_in_data[12]}]
set_property PACKAGE_PIN AD10 [get_ports {hdmi_in_data[11]}]
set_property PACKAGE_PIN AE9 [get_ports {hdmi_in_data[10]}]
set_property PACKAGE_PIN AG8 [get_ports {hdmi_in_data[9]}]
set_property PACKAGE_PIN AH8 [get_ports {hdmi_in_data[8]}]
set_property PACKAGE_PIN AE8 [get_ports {hdmi_in_data[7]}]
set_property PACKAGE_PIN AF8 [get_ports {hdmi_in_data[6]}]
set_property PACKAGE_PIN AJ6 [get_ports {hdmi_in_data[5]}]
set_property PACKAGE_PIN AJ5 [get_ports {hdmi_in_data[4]}]
set_property PACKAGE_PIN AE3 [get_ports {hdmi_in_data[3]}]
set_property PACKAGE_PIN AF3 [get_ports {hdmi_in_data[2]}]
set_property PACKAGE_PIN AH2 [get_ports {hdmi_in_data[1]}]
set_property PACKAGE_PIN AJ2 [get_ports {hdmi_in_data[0]}]
set_property PACKAGE_PIN AF6 [get_ports {hdmi_in_llc}]
# HDMI-in IO voltage
set_property IOSTANDARD LVCMOS18 [get_ports -regexp -nocase hdmi_in_.*]

# This parameter is needed to pass bitstream generation (calibration only needed for memory interfaces)
set_property UNAVAILABLE_DURING_CALIBRATION TRUE [get_ports hdmi_in_*]

# CDCE chip (Y4) for HDMI out pixel clock at up to 165MHz
create_clock -period 6.061 -name cdce_y4_clk [get_ports cdce_y4_clk]
set_property PACKAGE_PIN P11 [get_ports cdce_y4_clk]
set_property IOSTANDARD LVCMOS18 [get_ports cdce_y4_clk]
# CDCE chip (Y2) for SPDIF clock at ~12MHz
create_clock -period 81.380 -name hdmi_out_spdif_clk [get_ports cdce_y2_clk]
set_property PACKAGE_PIN G18 [get_ports cdce_y2_clk]
set_property IOSTANDARD LVCMOS33 [get_ports cdce_y2_clk]

# Set IDELAY to 0 for RGMII interface
set_property DELAY_VALUE  0   [get_cells -hier -filter {name =~ *tdkzu_trd_gmii_to_rgmii_0_0_core/*delay_rgmii_rx_ctl}]
set_property DELAY_VALUE  0   [get_cells -hier -filter {name =~ *tdkzu_trd_gmii_to_rgmii_0_0_core/*delay_rgmii_rxd*}]
set_property IODELAY_GROUP "gpr1" [get_cells -hier -filter {name =~ *tdkzu_trd_gmii_to_rgmii_0_0_core/*delay_rgmii_rx_ctl}]
set_property IODELAY_GROUP "gpr1" [get_cells -hier -filter {name =~ *tdkzu_trd_gmii_to_rgmii_0_0_core/*delay_rgmii_rxd*}]
set_property IODELAY_GROUP "gpr1" [get_cells -hier -filter {name =~ *i_tdkzu_trd_gmii_to_rgmii_0_0_idelayctrl}]

